# sensorbucket
SensorBucket processes data from different sources and devices into a single standardized format. 
An applications connected to SensorBucket, can use all devices SensorBucket supports.

Missing a device or source? SensorBucket is designed to be scalable and extendable. Create your own worker
that receives data from an AMQP source, process said data and output in the expected worker output format.

Find out more at: https://developer.sensorbucket.nl/

Developed and designed by Provincie Zeeland and Pollex'


This Python package is automatically generated by the [OpenAPI Generator](https://openapi-generator.tech) project:

- API version: 1.2.5
- Package version: v1.2.5
- Generator version: 7.9.0-SNAPSHOT
- Build package: org.openapitools.codegen.languages.PythonClientCodegen
For more information, please visit [https://sensorbucket.nl](https://sensorbucket.nl)

## Requirements.

Python 3.7+

## Installation & Usage
### pip install

If the python package is hosted on a repository, you can install directly using:

```sh
pip install git+https://github.com/sensorbucket.nl/PythonClient.git
```
(you may need to run `pip` with root permission: `sudo pip install git+https://github.com/sensorbucket.nl/PythonClient.git`)

Then import the package:
```python
import sensorbucket
```

### Setuptools

Install via [Setuptools](http://pypi.python.org/pypi/setuptools).

```sh
python setup.py install --user
```
(or `sudo python setup.py install` to install the package for all users)

Then import the package:
```python
import sensorbucket
```

### Tests

Execute `pytest` to run the tests.

## Getting Started

Please follow the [installation procedure](#installation--usage) and then run the following:

```python

import sensorbucket
from sensorbucket.rest import ApiException
from pprint import pprint

# Defining the host is optional and defaults to https://sensorbucket.nl/api
# See configuration.py for a list of all supported configuration parameters.
configuration = sensorbucket.Configuration(
    host = "https://sensorbucket.nl/api"
)

# The client must configure the authentication and authorization parameters
# in accordance with the API server security policy.
# Examples for each auth method are provided below, use the example that
# satisfies your auth use case.

# Configure Bearer authorization: APIKey
configuration = sensorbucket.Configuration(
    access_token = os.environ["BEARER_TOKEN"]
)

# Configure API key authorization: CookieSession
configuration.api_key['CookieSession'] = os.environ["API_KEY"]

# Uncomment below to setup prefix (e.g. Bearer) for API key, if needed
# configuration.api_key_prefix['CookieSession'] = 'Bearer'


# Enter a context with an instance of the API client
with sensorbucket.ApiClient(configuration) as api_client:
    # Create an instance of the API class
    api_instance = sensorbucket.APIKeysApi(api_client)
    create_api_key_request = sensorbucket.CreateApiKeyRequest() # CreateApiKeyRequest |  (optional)

    try:
        # Creates a new API key for the given Tenant
        api_response = api_instance.create_api_key(create_api_key_request=create_api_key_request)
        print("The response of APIKeysApi->create_api_key:\n")
        pprint(api_response)
    except ApiException as e:
        print("Exception when calling APIKeysApi->create_api_key: %s\n" % e)

```

This package has been extended with generator functions to iterate over SensorBucket pagination. If 
an endpoint returns a paginated response, a `{method}_gen` function should be available as shown
below:

```python
import sensorbucket as sb

cfg = sb.Configuration()

with sb.ApiClient(cfg) as api:
    devices = sb.DevicesApi(api)

    # This method will return a Generator which can be iterated over.
    # Every iteration returns a page of the results, the next iteration will return the next page
    # This can be used to lazily request all devices
    pages = devices.list_devices_gen()

    # A Generator can be used in a for loop
    for page in pages:
        print(page.data)

    # Or iterated over manually
    page1 = next(pages)
    page2 = next(pages)
    page3 = next(pages)
```

## Documentation for API Endpoints

All URIs are relative to *https://sensorbucket.nl/api*

Class | Method | HTTP request | Description
------------ | ------------- | ------------- | -------------
*APIKeysApi* | [**create_api_key**](docs/APIKeysApi.md#create_api_key) | **POST** /api-keys | Creates a new API key for the given Tenant
*APIKeysApi* | [**get_api_key**](docs/APIKeysApi.md#get_api_key) | **GET** /api-keys/{api_key_id} | Get an API Key by ID
*APIKeysApi* | [**list_api_keys**](docs/APIKeysApi.md#list_api_keys) | **GET** /api-keys | List API Keys
*APIKeysApi* | [**revoke_api_key**](docs/APIKeysApi.md#revoke_api_key) | **DELETE** /api-keys/{api_key_id} | Revokes an API key
*DevicesApi* | [**add_sensor_to_sensor_group**](docs/DevicesApi.md#add_sensor_to_sensor_group) | **POST** /sensor-groups/{id}/sensors | Add sensor to a sensor group
*DevicesApi* | [**create_device**](docs/DevicesApi.md#create_device) | **POST** /devices | Create device
*DevicesApi* | [**create_device_sensor**](docs/DevicesApi.md#create_device_sensor) | **POST** /devices/{device_id}/sensors | Create sensor for device
*DevicesApi* | [**create_sensor_group**](docs/DevicesApi.md#create_sensor_group) | **POST** /sensor-groups | Create sensor group
*DevicesApi* | [**delete_device**](docs/DevicesApi.md#delete_device) | **DELETE** /devices/{id} | Delete device
*DevicesApi* | [**delete_device_sensor**](docs/DevicesApi.md#delete_device_sensor) | **DELETE** /devices/{device_id}/sensors/{sensor_code} | Delete sensor
*DevicesApi* | [**delete_sensor_from_sensor_group**](docs/DevicesApi.md#delete_sensor_from_sensor_group) | **DELETE** /sensor-groups/{id}/sensors/{sensor_id} | Delete sensor from sensor group
*DevicesApi* | [**delete_sensor_group**](docs/DevicesApi.md#delete_sensor_group) | **DELETE** /sensor-groups/{id} | Delete sensor group
*DevicesApi* | [**get_device**](docs/DevicesApi.md#get_device) | **GET** /devices/{id} | Get device
*DevicesApi* | [**get_sensor**](docs/DevicesApi.md#get_sensor) | **GET** /devices/{device_id}/sensors/{sensor_code} | Get sensor
*DevicesApi* | [**get_sensor_group**](docs/DevicesApi.md#get_sensor_group) | **GET** /sensor-groups/{id} | Get sensor group
*DevicesApi* | [**list_device_sensors**](docs/DevicesApi.md#list_device_sensors) | **GET** /devices/{device_id}/sensors | List sensors device
*DevicesApi* | [**list_devices**](docs/DevicesApi.md#list_devices) | **GET** /devices | List devices
*DevicesApi* | [**list_sensor_groups**](docs/DevicesApi.md#list_sensor_groups) | **GET** /sensor-groups | List sensor groups
*DevicesApi* | [**list_sensors**](docs/DevicesApi.md#list_sensors) | **GET** /sensors | List sensors
*DevicesApi* | [**update_device**](docs/DevicesApi.md#update_device) | **PATCH** /devices/{id} | Update device properties
*DevicesApi* | [**update_sensor**](docs/DevicesApi.md#update_sensor) | **PATCH** /devices/{device_id}/sensors/{sensor_code} | Update sensor properties
*DevicesApi* | [**update_sensor_group**](docs/DevicesApi.md#update_sensor_group) | **PATCH** /sensor-groups/{id} | Update sensor group
*MeasurementsApi* | [**get_datastream**](docs/MeasurementsApi.md#get_datastream) | **GET** /datastreams/{id} | Get datastream
*MeasurementsApi* | [**list_datastreams**](docs/MeasurementsApi.md#list_datastreams) | **GET** /datastreams | List all datastreams
*MeasurementsApi* | [**query_measurements**](docs/MeasurementsApi.md#query_measurements) | **GET** /measurements | Query measurements
*PipelinesApi* | [**create_pipeline**](docs/PipelinesApi.md#create_pipeline) | **POST** /pipelines | Create pipeline
*PipelinesApi* | [**disable_pipeline**](docs/PipelinesApi.md#disable_pipeline) | **DELETE** /pipelines/{id} | Disable pipeline
*PipelinesApi* | [**get_pipeline**](docs/PipelinesApi.md#get_pipeline) | **GET** /pipelines/{id} | Get pipeline
*PipelinesApi* | [**list_pipelines**](docs/PipelinesApi.md#list_pipelines) | **GET** /pipelines | List pipelines
*PipelinesApi* | [**update_pipeline**](docs/PipelinesApi.md#update_pipeline) | **PATCH** /pipelines/{id} | Update pipeline
*TenantsApi* | [**add_tenant_member**](docs/TenantsApi.md#add_tenant_member) | **POST** /tenants/{tenant_id}/members | Add a User to a Tenant as member
*TenantsApi* | [**list_tenants**](docs/TenantsApi.md#list_tenants) | **GET** /tenants | Retrieves tenants
*TenantsApi* | [**remove_tenant_member**](docs/TenantsApi.md#remove_tenant_member) | **DELETE** /tenants/{tenant_id}/members/{user_id} | Removes a member from a tenant
*TenantsApi* | [**update_tenant_member**](docs/TenantsApi.md#update_tenant_member) | **PATCH** /tenants/{tenant_id}/members/{user_id} | Update a tenant member&#39;s permissions
*TracingApi* | [**list_ingresses**](docs/TracingApi.md#list_ingresses) | **GET** /ingresses | List ingresses
*TracingApi* | [**list_traces**](docs/TracingApi.md#list_traces) | **GET** /tracing | List traces
*UplinkApi* | [**process_uplink_data**](docs/UplinkApi.md#process_uplink_data) | **POST** /uplinks/{pipeline_id} | Process uplink message
*WorkersApi* | [**create_worker**](docs/WorkersApi.md#create_worker) | **POST** /workers | Create Worker
*WorkersApi* | [**get_worker**](docs/WorkersApi.md#get_worker) | **GET** /workers/{id} | Get worker
*WorkersApi* | [**get_worker_user_code**](docs/WorkersApi.md#get_worker_user_code) | **GET** /workers/{id}/usercode | Get the User Code for a Worker
*WorkersApi* | [**list_workers**](docs/WorkersApi.md#list_workers) | **GET** /workers | List workers
*WorkersApi* | [**update_worker**](docs/WorkersApi.md#update_worker) | **PATCH** /workers/{id} | Update worker properties


## Documentation For Models

 - [AddSensorToSensorGroup201Response](docs/AddSensorToSensorGroup201Response.md)
 - [AddSensorToSensorGroupRequest](docs/AddSensorToSensorGroupRequest.md)
 - [AddTenantMember201Response](docs/AddTenantMember201Response.md)
 - [AddTenantMemberRequest](docs/AddTenantMemberRequest.md)
 - [ApiError](docs/ApiError.md)
 - [ApiKey](docs/ApiKey.md)
 - [ApiKeyCreated](docs/ApiKeyCreated.md)
 - [ArchivedIngress](docs/ArchivedIngress.md)
 - [CreateApiKeyRequest](docs/CreateApiKeyRequest.md)
 - [CreateDevice201Response](docs/CreateDevice201Response.md)
 - [CreateDeviceRequest](docs/CreateDeviceRequest.md)
 - [CreateDeviceSensor201Response](docs/CreateDeviceSensor201Response.md)
 - [CreatePipeline200Response](docs/CreatePipeline200Response.md)
 - [CreatePipelineRequest](docs/CreatePipelineRequest.md)
 - [CreateSensorGroup201Response](docs/CreateSensorGroup201Response.md)
 - [CreateSensorGroupRequest](docs/CreateSensorGroupRequest.md)
 - [CreateSensorRequest](docs/CreateSensorRequest.md)
 - [CreateUserWorkerRequest](docs/CreateUserWorkerRequest.md)
 - [CreateWorker201Response](docs/CreateWorker201Response.md)
 - [Datastream](docs/Datastream.md)
 - [DeleteDevice200Response](docs/DeleteDevice200Response.md)
 - [DeleteDeviceSensor200Response](docs/DeleteDeviceSensor200Response.md)
 - [DeleteSensorFromSensorGroup200Response](docs/DeleteSensorFromSensorGroup200Response.md)
 - [DeleteSensorGroup200Response](docs/DeleteSensorGroup200Response.md)
 - [Device](docs/Device.md)
 - [DisablePipeline200Response](docs/DisablePipeline200Response.md)
 - [GetDatastream200Response](docs/GetDatastream200Response.md)
 - [GetDatastream200ResponseData](docs/GetDatastream200ResponseData.md)
 - [GetDevice200Response](docs/GetDevice200Response.md)
 - [GetPipeline200Response](docs/GetPipeline200Response.md)
 - [GetSensor200Response](docs/GetSensor200Response.md)
 - [GetSensorGroup200Response](docs/GetSensorGroup200Response.md)
 - [GetWorker200Response](docs/GetWorker200Response.md)
 - [GetWorkerUserCode200Response](docs/GetWorkerUserCode200Response.md)
 - [IngressDTO](docs/IngressDTO.md)
 - [ListApiKeys200Response](docs/ListApiKeys200Response.md)
 - [ListDatastreams200Response](docs/ListDatastreams200Response.md)
 - [ListDeviceSensors200Response](docs/ListDeviceSensors200Response.md)
 - [ListDevices200Response](docs/ListDevices200Response.md)
 - [ListIngresses200Response](docs/ListIngresses200Response.md)
 - [ListPipelines200Response](docs/ListPipelines200Response.md)
 - [ListSensorGroups200Response](docs/ListSensorGroups200Response.md)
 - [ListTenants200Response](docs/ListTenants200Response.md)
 - [ListTraces200Response](docs/ListTraces200Response.md)
 - [ListWorkers200Response](docs/ListWorkers200Response.md)
 - [Measurement](docs/Measurement.md)
 - [PaginatedResponse](docs/PaginatedResponse.md)
 - [PaginatedResponseLinks](docs/PaginatedResponseLinks.md)
 - [Pipeline](docs/Pipeline.md)
 - [QueryMeasurements200Response](docs/QueryMeasurements200Response.md)
 - [RemoveTenantMember200Response](docs/RemoveTenantMember200Response.md)
 - [RevokeApiKey200Response](docs/RevokeApiKey200Response.md)
 - [Sensor](docs/Sensor.md)
 - [SensorGroup](docs/SensorGroup.md)
 - [Tenant](docs/Tenant.md)
 - [Trace](docs/Trace.md)
 - [TraceStep](docs/TraceStep.md)
 - [UpdateDevice200Response](docs/UpdateDevice200Response.md)
 - [UpdateDeviceRequest](docs/UpdateDeviceRequest.md)
 - [UpdatePipeline200Response](docs/UpdatePipeline200Response.md)
 - [UpdatePipelineRequest](docs/UpdatePipelineRequest.md)
 - [UpdateSensor200Response](docs/UpdateSensor200Response.md)
 - [UpdateSensorGroup200Response](docs/UpdateSensorGroup200Response.md)
 - [UpdateSensorGroupRequest](docs/UpdateSensorGroupRequest.md)
 - [UpdateSensorRequest](docs/UpdateSensorRequest.md)
 - [UpdateTenantMemberRequest](docs/UpdateTenantMemberRequest.md)
 - [UpdateWorker200Response](docs/UpdateWorker200Response.md)
 - [UpdateWorkerRequest](docs/UpdateWorkerRequest.md)
 - [UserWorker](docs/UserWorker.md)


<a id="documentation-for-authorization"></a>
## Documentation For Authorization


Authentication schemes defined for the API:
<a id="CookieSession"></a>
### CookieSession

- **Type**: API key
- **API key parameter name**: SID
- **Location**: 

<a id="APIKey"></a>
### APIKey

- **Type**: Bearer authentication


## Author

info@pollex.nl


